/***************************************************************************
 $RCSfile$
                             -------------------
    cvs         : $Id: textmatcher.h 284 2005-08-26 02:45:39Z aquamaniac $
    begin       : Mon Mar 01 2004
    copyright   : (C) 2004 by Martin Preuss
    email       : martin@libchipcard.de

 ***************************************************************************
 *          Please see toplevel file COPYING for license details           *
 ***************************************************************************/

#ifndef AQBANKING_KDE_TEXTMATCHER_H
#define AQBANKING_KDE_TEXTMATCHER_H


#include "textmatcher.ui.h"

#include <gwenhywfar/db.h>


class TextMatcher : public TextMatcherUi {
  Q_OBJECT
public:
  TextMatcher(QWidget* parent=0,
              const char* name=0,
              WFlags fl=0);
  virtual ~TextMatcher();

  void setLabel(const QString &text);

  bool fromDb(GWEN_DB_NODE *db);
  bool toDb(GWEN_DB_NODE *db) const;
  void resetRule();

};





#endif
